@@ -111,7 +111,6 @@ enum
 };
 
 
-
 /* list display operation (dsp_account) */
 enum
 {
@@ -126,9 +125,12 @@ enum
 	LST_DSPOPE_INCOME,	/* fake column */
 	LST_DSPOPE_CATEGORY,	/* fake column */
 	LST_DSPOPE_TAGS,	/* fake column */
+	/* here we insert accoutn column, only used for detail */
+	LST_DSPOPE_ACCOUNT,
 	NUM_LST_DSPOPE
 };
 
+
 /* list define archive (defarchive) */
 enum
 {
