@@ -120,6 +120,8 @@ struct import_target_data
 
 GtkWidget *create_import_window (void);
 Account *import_create_account(gchar *name, gchar *number);
+const gchar *homebank_file_getencoding(gchar *filename);
+gchar *homebank_utf8_ensure(gchar *buffer);
 
 #endif
 
