@@ -20,7 +20,15 @@
 #ifndef __LIST_OPERATION__H__
 #define __LIST_OPERATION__H__
 
-GtkWidget *create_list_operation(gboolean *columns);
+enum {
+	TRN_LIST_TYPE_BOOK,
+	TRN_LIST_TYPE_DETAIL,
+	TRN_LIST_TYPE_IMPORT,
+};
+
+
+
+GtkWidget *create_list_operation(gint type, gboolean *pref_columns);
 GtkWidget *create_list_import_operation(void);
 
 #endif /* __LIST_OPERATION__H__ */
