@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2010 Maxime DOYEN
+ *  Copyright (C) 1995-2011 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -58,6 +58,7 @@ struct repbudget_data
 	GtkWidget	*TB_bar;
 
 	GtkWidget	*TX_info;
+	GtkWidget	*TX_daterange;
 	GtkWidget	*CM_minor;
 	GtkWidget	*CY_for;
 	GtkWidget	*CY_kind;
@@ -116,15 +117,28 @@ extern gchar *CYA_SELECT[];
 static GtkActionEntry entries[] = {
   { "List"    , "hb-view-list" , N_("List")  , NULL,    N_("View results as list"), G_CALLBACK (repbudget_action_viewlist) },
   { "Bar"     , "hb-view-bar"  , N_("Bar")   , NULL,    N_("View results as bars"), G_CALLBACK (repbudget_action_viewbar) },
-
-  { "Detail"  , "hb-ope-show"  , N_("Detail"), NULL,    N_("Toggle detail"), G_CALLBACK (repbudget_action_detail) },
-  { "Legend"  , "hb-legend"    , N_("Legend"), NULL,    N_("Toggle legend"), G_CALLBACK (repbudget_action_legend) },
-
   { "Refresh" , GTK_STOCK_REFRESH, N_("Refresh"), NULL,   N_("Refresh results"), G_CALLBACK (repbudget_action_refresh) },
 };
-
 static guint n_entries = G_N_ELEMENTS (entries);
 
+
+static GtkToggleActionEntry toggle_entries[] = {
+  { "Detail", "hb-ope-show",                    /* name, stock id */
+     N_("Detail"), NULL,                    /* label, accelerator */     
+    N_("Toggle detail"),                                    /* tooltip */
+    G_CALLBACK (repbudget_action_detail), 
+    FALSE },                                    /* is_active */
+
+  { "Legend", "hb-legend",                    /* name, stock id */
+     N_("Legend"), NULL,                    /* label, accelerator */     
+    N_("Toggle legend"),                                    /* tooltip */
+    G_CALLBACK (repbudget_action_legend), 
+    TRUE },                                    /* is_active */
+	
+};
+static guint n_toggle_entries = G_N_ELEMENTS (toggle_entries);
+
+
 static const gchar *ui_info =
 "<ui>"
 "  <toolbar name='ToolBar'>"
@@ -164,6 +178,7 @@ static void repbudget_toggle_legend(GtkWidget *widget, gpointer user_data);
 static void repbudget_toggle(GtkWidget *widget, gpointer user_data);
 static GtkWidget *create_list_budget(void);
 static void repbudget_update_detail(GtkWidget *widget, gpointer user_data);
+static void repbudget_update_daterange(GtkWidget *widget, gpointer user_data);
 
 /* action functions -------------------- */
 static void repbudget_action_viewlist(GtkAction *action, gpointer user_data)
@@ -278,7 +293,13 @@ struct repbudget_data *data;
 	data->mindate = gtk_dateentry_get_date(GTK_DATE_ENTRY(data->PO_mindate));
 	data->maxdate = gtk_dateentry_get_date(GTK_DATE_ENTRY(data->PO_maxdate));
 
+	g_signal_handler_block(data->CY_range, data->handler_id[HID_RANGE]);
+	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_range), 0);
+	g_signal_handler_unblock(data->CY_range, data->handler_id[HID_RANGE]);
+
+	
 	repbudget_compute(widget, NULL);
+	repbudget_update_daterange(widget, NULL);
 
 }
 
@@ -319,6 +340,7 @@ gint month, year;
 	g_signal_handler_unblock(data->PO_maxdate, data->handler_id[HID_MAXDATE]);
 
 	repbudget_compute(widget, NULL);
+	repbudget_update_daterange(widget, NULL);
 
 }
 
@@ -374,9 +396,37 @@ GDate *date;
 		g_signal_handler_unblock(data->PO_maxdate, data->handler_id[HID_MAXDATE]);
 
 		repbudget_compute(widget, NULL);
+		repbudget_update_daterange(widget, NULL);
 	}
 }
 
+
+static void repbudget_update_daterange(GtkWidget *widget, gpointer user_data)
+{
+struct repbudget_data *data;
+
+	DB( g_print("(repbudget) update daterange\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	gchar buffer1[128];
+	gchar buffer2[128];
+	GDate *date;
+	gchar *info;
+
+		date = g_date_new_julian(data->mindate);
+		g_date_strftime (buffer1, 128-1, PREFS->date_format, date);
+		g_date_set_julian(date, data->maxdate);
+		g_date_strftime (buffer2, 128-1, PREFS->date_format, date);
+		g_date_free(date);
+
+		info = g_strdup_printf(_("<i>from</i> %s <i>to</i> %s"), buffer1, buffer2);
+
+		gtk_label_set_markup(GTK_LABEL(data->TX_daterange), info);
+
+
+		g_free(info);
+}	
 static void repbudget_toggle_detail(GtkWidget *widget, gpointer user_data)
 {
 struct repbudget_data *data;
@@ -766,7 +816,7 @@ next1:
 					continue;
 
 
-				if(tmp_budget[pos] || tmp_spent[pos])
+				if(tmp_budget[pos] || entry->flags & GF_FORCED /*|| tmp_spent[pos]*/)
 				{
 				gdouble decay;
 				
@@ -872,6 +922,7 @@ gint page;
 
 	sensitive = page == 0 ? FALSE : TRUE;
 	gtk_widget_set_sensitive(data->CY_view, sensitive);
+	gtk_widget_set_sensitive(data->RG_zoomx, sensitive);
 //	gtk_widget_set_sensitive(data->TB_buttons[ACTION_REPBUDGET_LEGEND], sensitive);
 	gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/ToolBar/Legend"), sensitive);
 
@@ -1128,6 +1179,11 @@ GError *error = NULL;
 	// data to action callbacks is set here (data)
 	gtk_action_group_add_actions (actions, entries, n_entries, data);
 
+     gtk_action_group_add_toggle_actions (actions, 
+					   toggle_entries, n_toggle_entries, 
+					   data);
+
+	
 	/* set which action should have priority in the toolbar */
 	action = gtk_action_group_get_action(actions, "List");
 	g_object_set(action, "is_important", TRUE, NULL);
@@ -1138,9 +1194,6 @@ GError *error = NULL;
 	action = gtk_action_group_get_action(actions, "Detail");
 	g_object_set(action, "is_important", TRUE, NULL);
 
-	action = gtk_action_group_get_action(actions, "Legend");
-	g_object_set(action, "is_important", TRUE, NULL);
-
 	action = gtk_action_group_get_action(actions, "Refresh");
 	g_object_set(action, "is_important", TRUE, NULL);
 
@@ -1163,15 +1216,15 @@ GError *error = NULL;
 
 	//infos
 	hbox = gtk_hbox_new (FALSE, HB_BOX_SPACING);
+	gtk_container_set_border_width (GTK_CONTAINER(hbox), HB_BOX_SPACING);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-	gtk_container_set_border_width (GTK_CONTAINER(hbox), HB_BOX_SPACING);
+	widget = make_label(NULL, 0.5, 0.5);
+	gimp_label_set_attributes (GTK_LABEL (widget), PANGO_ATTR_SCALE,  PANGO_SCALE_SMALL, -1);
+	data->TX_daterange = widget;
+	gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
 
-/*
-	label = gtk_label_new(NULL);
-	data->TX_info = label;
-	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
-*/
+	
 	entry = gtk_label_new(NULL);
 	data->TX_total[2] = entry;
 	gtk_box_pack_end (GTK_BOX (hbox), entry, FALSE, FALSE, 0);
