@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2010 Maxime DOYEN
+ *  Copyright (C) 1995-2011 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -75,6 +75,7 @@ struct statistic_data
 	GtkWidget	*CY_range;
 	GtkWidget	*GR_result;
 
+	GtkWidget	*TX_daterange;
 	GtkWidget	*TX_total[3];
 
 	GtkWidget	*RE_bar;
@@ -121,6 +122,7 @@ static void statistic_action_filter(GtkAction *action, gpointer user_data);
 static void statistic_action_refresh(GtkAction *action, gpointer user_data);
 static void statistic_action_export(GtkAction *action, gpointer user_data);
 
+
 static void statistic_busy(GtkWidget *widget, gboolean state);
 
 
@@ -129,18 +131,37 @@ static GtkActionEntry entries[] = {
   { "Bar"     , "hb-view-bar"  , N_("Bar")    , NULL,    N_("View results as bars"), G_CALLBACK (statistic_action_viewbar) },
   { "Pie"     , "hb-view-pie"  , N_("Pie")    , NULL,    N_("View results as pies"), G_CALLBACK (statistic_action_viewpie) },
 
-  { "Detail"  , "hb-ope-show"  , N_("Detail") , NULL,    N_("Toggle detail"), G_CALLBACK (statistic_action_detail) },
-  { "Legend"  , "hb-legend"    , N_("Legend") , NULL,    N_("Toggle legend"), G_CALLBACK (statistic_action_legend) },
-  { "Rate"    , "hb-rate"      , N_("Rate")   , NULL,    N_("Toggle rate")  , G_CALLBACK (statistic_action_rate) },
-
   { "Filter"  , "hb-filter"    , N_("Filter") , NULL,   N_("Edit the filter"), G_CALLBACK (statistic_action_filter) },
   { "Refresh" , GTK_STOCK_REFRESH   , N_("Refresh"), NULL,   N_("Refresh results"), G_CALLBACK (statistic_action_refresh) },
 
   { "Export" , "hb-file-export", N_("Export")  , NULL,   N_("Export as CSV"), G_CALLBACK (statistic_action_export) },
 };
-
 static guint n_entries = G_N_ELEMENTS (entries);
 
+static GtkToggleActionEntry toggle_entries[] = {
+  { "Detail", "hb-ope-show",                    /* name, stock id */
+     N_("Detail"), NULL,                    /* label, accelerator */     
+    N_("Toggle detail"),                                    /* tooltip */
+    G_CALLBACK (statistic_action_detail), 
+    FALSE },                                    /* is_active */
+
+  { "Legend", "hb-legend",                    /* name, stock id */
+     N_("Legend"), NULL,                    /* label, accelerator */     
+    N_("Toggle legend"),                                    /* tooltip */
+    G_CALLBACK (statistic_action_legend), 
+    TRUE },                                    /* is_active */
+
+  { "Rate", "hb-rate",                    /* name, stock id */
+     N_("Rate"), NULL,                    /* label, accelerator */     
+    N_("Toggle rate"),                                    /* tooltip */
+    G_CALLBACK (statistic_action_rate), 
+    FALSE },                                    /* is_active */
+	
+};
+static guint n_toggle_entries = G_N_ELEMENTS (toggle_entries);
+
+
+
 static const gchar *ui_info =
 "<ui>"
 "  <toolbar name='ToolBar'>"
@@ -189,6 +210,7 @@ static void statistic_toggle_legend(GtkWidget *widget, gpointer user_data);
 static void statistic_toggle_minor(GtkWidget *widget, gpointer user_data);
 static void statistic_toggle_rate(GtkWidget *widget, gpointer user_data);
 static GtkWidget *create_list_statistic(void);
+static void statistic_update_daterange(GtkWidget *widget, gpointer user_data);
 
 static gint stat_list_compare_func (GtkTreeModel *model, GtkTreeIter  *a, GtkTreeIter  *b, gpointer      userdata);
 
@@ -413,7 +435,13 @@ struct statistic_data *data;
 	data->filter->mindate = gtk_dateentry_get_date(GTK_DATE_ENTRY(data->PO_mindate));
 	data->filter->maxdate = gtk_dateentry_get_date(GTK_DATE_ENTRY(data->PO_maxdate));
 
+	g_signal_handler_block(data->CY_range, data->handler_id[HID_RANGE]);
+	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_range), 0);
+	g_signal_handler_unblock(data->CY_range, data->handler_id[HID_RANGE]);
+
+	
 	statistic_compute(widget, NULL);
+	statistic_update_daterange(widget, NULL);
 
 }
 
@@ -459,6 +487,7 @@ gint month, year;
 	data->filter->range = 0;
 
 	statistic_compute(widget, NULL);
+	statistic_update_daterange(widget, NULL);
 
 }
 
@@ -520,6 +549,7 @@ GDate *date;
 		g_date_free(date);
 
 		statistic_compute(widget, NULL);
+		statistic_update_daterange(widget, NULL);
 	}
 }
 
@@ -739,6 +769,33 @@ gboolean xval;
 	
 }
 
+static void statistic_update_daterange(GtkWidget *widget, gpointer user_data)
+{
+struct statistic_data *data;
+
+	DB( g_print("(statistic) update daterange\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	gchar buffer1[128];
+	gchar buffer2[128];
+	GDate *date;
+	gchar *info;
+
+		date = g_date_new_julian(data->filter->mindate);
+		g_date_strftime (buffer1, 128-1, PREFS->date_format, date);
+		g_date_set_julian(date, data->filter->maxdate);
+		g_date_strftime (buffer2, 128-1, PREFS->date_format, date);
+		g_date_free(date);
+
+		info = g_strdup_printf(_("<i>from</i> %s <i>to</i> %s"), buffer1, buffer2);
+
+		gtk_label_set_markup(GTK_LABEL(data->TX_daterange), info);
+
+
+		g_free(info);
+}	
+
 static void statistic_update_total(GtkWidget *widget, gpointer user_data)
 {
 struct statistic_data *data;
@@ -1170,7 +1227,7 @@ gint page;
 
 	
 	sensitive = page == 0 ? FALSE : TRUE;
-	//gtk_widget_set_sensitive(data->CY_view, sensitive);
+	gtk_widget_set_sensitive(data->RG_zoomx, sensitive);
 //	gtk_widget_set_sensitive(data->TB_buttons[ACTION_REPBUDGET_LEGEND], sensitive);
 	gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/ToolBar/Legend"), sensitive);
 
@@ -1617,6 +1674,11 @@ GError *error = NULL;
 	// data to action callbacks is set here (data)
 	gtk_action_group_add_actions (actions, entries, n_entries, data);
 
+     gtk_action_group_add_toggle_actions (actions, 
+					   toggle_entries, n_toggle_entries, 
+					   data);
+
+
 	/* set which action should have priority in the toolbar */
 	action = gtk_action_group_get_action(actions, "List");
 	g_object_set(action, "is_important", TRUE, NULL);
@@ -1654,17 +1716,16 @@ GError *error = NULL;
 	data->TB_bar = gtk_ui_manager_get_widget (ui, "/ToolBar");
 	gtk_box_pack_start (GTK_BOX (vbox), data->TB_bar, FALSE, FALSE, 0);
 
-	//infos + minor
+	//infos + balance
 	hbox = gtk_hbox_new (FALSE, HB_BOX_SPACING);
+	gtk_container_set_border_width (GTK_CONTAINER(hbox), HB_BOX_SPACING);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-	gtk_container_set_border_width (GTK_CONTAINER(hbox), HB_BOX_SPACING);
+	widget = make_label(NULL, 0.5, 0.5);
+	gimp_label_set_attributes (GTK_LABEL (widget), PANGO_ATTR_SCALE,  PANGO_SCALE_SMALL, -1);
+	data->TX_daterange = widget;
+	gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
 
-/*
-	label = gtk_label_new(NULL);
-	data->TX_info = label;
-	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
-*/
 	entry = gtk_label_new(NULL);
 	data->TX_total[2] = entry;
 	gtk_box_pack_end (GTK_BOX (hbox), entry, FALSE, FALSE, 0);
