@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2010 Maxime DOYEN
+ *  Copyright (C) 1995-2011 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -1058,6 +1058,7 @@ GtkTreeIter			 iter, child_iter;
 		gtk_entry_set_text(GTK_ENTRY(w_name), item->name);
 		gtk_widget_grab_focus (w_name);
 
+		gtk_entry_set_activates_default (GTK_ENTRY(w_name), TRUE);
 
 		if(!(item->flags & GF_SUB))
 		{
@@ -1068,6 +1069,8 @@ GtkTreeIter			 iter, child_iter;
 
 		gtk_widget_show_all(mainvbox);
 
+		gtk_dialog_set_default_response(GTK_DIALOG( window ), GTK_RESPONSE_ACCEPT);
+		
 		//wait for the user
 		gint result = gtk_dialog_run (GTK_DIALOG (window));
 
@@ -1508,8 +1511,6 @@ gint row;
 
 	data.window = window;
 
-	gtk_dialog_set_has_separator(GTK_DIALOG (window), FALSE);
-	
 	//set the window icon
 	//homebank_window_set_icon_from_file(GTK_WINDOW (window), "category.svg");
 	gtk_window_set_icon_name(GTK_WINDOW (window), HB_STOCK_CATEGORY);
